#include <AFMotor.h>

// Motor definitions
AF_DCMotor motorRight(1); // Motor on port 1 for right wheel
AF_DCMotor motorLeft(3);  // Motor on port 3 for left wheel
AF_DCMotor motorExtra(2); // Motor on port 2

// Ultrasonic sensor pins
const int trigPin = A1; // Interchanged pin
const int echoPin = A0; // Interchanged pin

// Variables for distance measurement
long duration;
int distance;
bool rotating = false;
bool rotateLeft = false;

void setup() {
  // Initialize motors
  Serial.begin(115200);           // Set up Serial library at 9600 bps
  Serial.println("Motor test!");

  motorRight.setSpeed(100);
  motorLeft.setSpeed(100);
  motorExtra.setSpeed(200);
  
  motorRight.run(RELEASE);
  motorLeft.run(RELEASE);
  motorExtra.run(RELEASE);
  
  // Initialize ultrasonic sensor pins
  pinMode(trigPin, OUTPUT); // Sets the trigPin as an Output
  pinMode(echoPin, INPUT);  // Sets the echoPin as an Input

  // Initialize random seed
  randomSeed(analogRead(0));
}

void loop() {
  // Measure distance using ultrasonic sensor
  digitalWrite(trigPin, LOW);
  delayMicroseconds(2);
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);
  
  duration = pulseIn(echoPin, HIGH);
  distance = duration * 0.034 / 2;
  
  Serial.print("Distance: ");
  Serial.println(distance);

  if (distance > 30) {
    if (!rotating) {
      // Randomize rotation direction
      rotateLeft = random(2) == 0;
      rotating = true;
    }

    if (rotateLeft) {
      motorRight.run(FORWARD);
      motorLeft.run(BACKWARD);
    } else {
      motorRight.run(BACKWARD);
      motorLeft.run(FORWARD);
    }

    motorExtra.run(RELEASE); // Ensure motorExtra is stopped
  } else {
    rotating = false;

    if (distance < 25) {
      // Move forward and run motorExtra
      motorRight.run(FORWARD);
      motorLeft.run(FORWARD);
      motorExtra.run(FORWARD); // Run motorExtra when distance < 60 cm
    } else {
      // Move forward
      motorRight.run(FORWARD);
      motorLeft.run(FORWARD);
      motorExtra.run(RELEASE); // Ensure motorExtra is stopped
    }
  }

  // Small delay to allow ultrasonic sensor to update
  delay(100); 
}
